From: Arne Meyer <meyer.arne83@netcologne.de>
Date: Fri, 26 Jul 2024 19:40:21 +0000
Subject: [PATCH 1/3] ip/ipconfig: only accept ras with medium default router preference


according to rfc4191 section 3 9front is a type a host, we do not know about
default router preferences. If there were more than one router that announce
the same prefix with different router preferences the default gateway would
flap with each ra from the different routers.
---
diff da46286598aad11695b2aa4b6ad9ed9ec0852c18 2101ee76fa44706c777154bd18b07a22dbec12ca
--- a/sys/src/cmd/ip/ipconfig/ipv6.c
+++ b/sys/src/cmd/ip/ipconfig/ipv6.c
@@ -694,6 +694,9 @@
 		if(prfo->len != 4)
 			continue;
 
+		if((prfo->lar>>3)&3)
+			continue;
+
 		if((prfo->lar & AFMASK) == 0)
 			continue;
 

From: Arne Meyer <meyer.arne83@netcologne.de>
Date: Fri, 26 Jul 2024 19:54:57 +0000
Subject: [PATCH 2/3] ip/ipconfig: stop sending router solicitations after getting an answer


rfc 4261 section 6.3.7 says we MUST stop sending solicitations after we
get a valid ra in response.
---
diff 2101ee76fa44706c777154bd18b07a22dbec12ca 355d76951f895fae77b321ea9d7d591d6c3237cf
--- a/sys/src/cmd/ip/ipconfig/ipv6.c
+++ b/sys/src/cmd/ip/ipconfig/ipv6.c
@@ -887,6 +887,8 @@
 
 		if(recvrahost(buf, n) < 0)
 			continue;
+		else
+			sendrscnt = 0;
 
 		/* got at least initial ra; no whining */
 		if(recvracnt == 0){

From: Arne Meyer <meyer.arne83@netcologne.de>
Date: Sat, 27 Jul 2024 12:25:52 +0000
Subject: [PATCH 3/3] ip/ipconfig: remove rate limiting for receiving ras


this code is meant to be a protection against someone flooding the network
with ras. Some cpe routers send a lot of ras when a renumbering event, like
a reconnect, happens. So sometimes we would miss the ra with the new prefix in
and be without a default ipv6 route until the next regular ra comes in.
So remove this for now until we find a better way to protect against flooding.
---
diff 355d76951f895fae77b321ea9d7d591d6c3237cf b72460c5eb31a6f8fb0c70835c2fd68bef3de9b9
--- a/sys/src/cmd/ip/ipconfig/ipv6.c
+++ b/sys/src/cmd/ip/ipconfig/ipv6.c
@@ -844,11 +844,7 @@
 	for (;;) {
 		alarm(sleepfor);
 		n = read(fd, buf, sizeof buf);
-		sleepfor = alarm(0);
-
-		/* wait for alarm to expire */
-		if(recvracnt >= Maxv6initras && sleepfor > 100)
-			continue;
+		alarm(0);
 
 		sleepfor = Maxv6radelay;
 
